@@ -6,10 +6,16 @@ c     include file instead of subroutine to avoid recursion pbs. This file
 c     must be included in each routine which compute an external
  60   call  parse
       if(fun.eq.99) then
+         if(err.gt.0.or.err1.gt.0) then
+c     .     test if we are under errcatch('stop') mode (imode=3)           
+            imode=mod(abs(errct)/100000,8)
+            if (imode.ne.3) goto 97
+         endif
          fun=0
          goto 200
       endif
       if(err.gt.0) goto 97
+
 c     
 
       if(int(rstk(pt)/100).eq.9) then
@@ -17,7 +23,7 @@ c
          if(ir.eq.1) then
 c     .     back to matsys
             k=13
-         elseif(ir.ge.2.and.ir.le.9) then
+         elseif((ir.ge.2.and.ir.le.9).or.ir.eq.13) then
 c     .     back to matio
             k=5
          elseif(ir.eq.10) then
