@@ -13,9 +13,9 @@
 #include <math.h>
 #include <stdio.h>
 #ifdef __STDC__
-#include <stdlib.h>
+	#include <stdlib.h>
 #else 
-#include <malloc.h>
+	#include <malloc.h>
 #endif
 #include <string.h>
 
@@ -26,9 +26,9 @@
 #include "../os_specific/Os_specific.h"
 
 #ifdef WIN32
-#include "../os_specific/win_mem_alloc.h" /* MALLOC */
+	#include "../os_specific/win_mem_alloc.h" /* MALLOC */
 #else
-#include "../os_specific/sci_mem_alloc.h" /* MALLOC */
+	#include "../os_specific/sci_mem_alloc.h" /* MALLOC */
 #endif
 /*-----------------------------------------------------------------------------------*/
 typedef union {
@@ -62,7 +62,7 @@ typedef int (*FLUSH) __PARAMS((FILE *));
 #define NOT_ENOUGH_ARGS -5
 /*if maxscan is increased don't forget to chage the (*printer)(......) 
 in do_scanf procedure */
-#define MAXSCAN 50
+#define MAXSCAN 100
 /*---------- types and defs for doing printf ------------*/
 #define  PF_C		0
 #define  PF_S		1
@@ -111,7 +111,7 @@ static int ReadLine __PARAMS((FILE *fd,int *mem));
 
 /*-----------------------------------------------------------------------------------*/
 /*********************************************************************
- * Scilab printf function OK 
+ * Scilab printf function
  *********************************************************************/
 int int_objprintf(char *fname,unsigned long fname_len)
 {
@@ -175,7 +175,7 @@ int int_objprintf(char *fname,unsigned long fname_len)
 }  
 /*-----------------------------------------------------------------------------------*/
 /*********************************************************************
- * Scilab fprintf function OK 
+ * Scilab fprintf function
  *********************************************************************/
 int int_objfprintf(char *fname,unsigned long fname_len)
 {
@@ -245,7 +245,7 @@ int int_objfprintf(char *fname,unsigned long fname_len)
 }  
 /*-----------------------------------------------------------------------------------*/
 /*********************************************************************
- * Scilab sprintf function OK 
+ * Scilab sprintf function
  *********************************************************************/
 int int_objsprintf(char *fname,unsigned long fname_len)
 {
@@ -306,7 +306,14 @@ int int_objsprintf(char *fname,unsigned long fname_len)
 	  if (! cat_to_last) { /*add a new line */
 	    if (n==nmax) {
 	      nmax+=blk;
-	      if ( (strs = (char **) REALLOC(strs,nmax*sizeof(char **))) == NULL) goto mem;
+		  if ( strs != NULL )
+		  {
+			if ( (strs = (char **) REALLOC(strs,nmax*sizeof(char **))) == NULL) { goto mem; }
+		  }
+		  else
+		  {
+			if ( (strs = (char **) MALLOC( nmax * sizeof(char **))) == NULL) { goto mem ; }
+		  }
 	    }
 	    if ((strs[n]=MALLOC((k+1))) == NULL) goto mem;
 	    strncpy(strs[n],str1, k);
@@ -388,75 +395,92 @@ int int_objscanf(char *fname,unsigned long fname_len)
 
   Nbvars = 0;
   CheckRhs(1,2);
-  if (Rhs==2) {
+  if (Rhs==2) 
+	{
     GetRhsVar(1,"i",&m1,&n1,&l1);
-    if (m1*n1 != 1) {
+    if (m1*n1 != 1) 
+		{
       Scierror(999,"Error: in scanf: incorrect first argument\r\n");
       return 0;
     }
     iarg=2;
     maxrow=*istk(l1);
-
   }
-  else {
+  else 
+	{
     iarg=1;
     maxrow=1;
   }
+
   GetRhsVar(iarg,"c",&m1,&n1,&l1); /** format **/
   n_count=StringConvert(cstk(l1))+1;  /* conversion */
+
   /** Read a line with Scilab read function **/
   C2F(xscion)(&iflag);
-  if (n_count>1) {
+
+  if (n_count>1) 
+	{
     Scierror(999,"Error: in scanf: format cannot include \\n \r\n");
     return 0;
   }
 
   nrow=maxrow; 
   rowcount = -1; /* number-1 of result lines already got */
-  while (1) {
+  while (1)
+	{
     rowcount++;
     if ((maxrow >= 0) && (rowcount >= maxrow)) break;
+
     /* get a line */
     C2F(xscion)(&iflag);
     C2F(zzledt)(String,&len,&lline,&status,&interrupt,&iflag,strlen(String));
 
     if(status != 0) 
-      {
-	Scierror(999,"Error: in scanf\r\n");
-	return 0;
-      }
+    {
+			Scierror(999,"Error: in scanf\r\n");
+			return 0;
+    }
+
     if (lline == 0) {String[0] = ' ';lline=1;}
     /** use the scaned line as input **/
     args = Rhs; /* args set to Rhs on entry */
     if (do_scanf("scanf",(FILE *) 0,cstk(l1),&args,String,&retval,buf,type) < 0) return 0;
-    if ( retval == EOF) {
+
+    if ( retval == EOF)
+		{
       /* 
-	 Scierror(999,"Error: in %s: end of file reached\r\n",fname);
-	 return 0;
+				Scierror(999,"Error: in %s: end of file reached\r\n",fname);
+				return 0;
       */
     }
-    if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,
-			buf,&data,rowcount,args)) <0 ) {
-      switch (err) {
-      case MISMATCH:
-	if (maxrow>=0) {
-	  Free_Scan(rowcount,ncol,type_s,&data);
-	  Scierror(999,"Error: in fscanf: data mismatch\r\n");
-	  return 0;
-	}
-	break;
-      case MEM_LACK:
-	Free_Scan(rowcount,ncol,type_s,&data);
-	Scierror(999,"Error: in scanf: cannot allocate more memory \r\n");
-	return 0;
-	break;
+
+    if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,buf,&data,rowcount,args)) <0 )
+		{
+      switch (err)
+			{
+				case MISMATCH:
+					if (maxrow>=0)
+					{
+						Free_Scan(rowcount,ncol,type_s,&data);
+						Scierror(999,"Error: in fscanf: data mismatch\r\n");
+						return 0;
+					}
+				break;
+
+				case MEM_LACK:
+					Free_Scan(rowcount,ncol,type_s,&data);
+					Scierror(999,"Error: in scanf: cannot allocate more memory \r\n");
+					return 0;
+				break;
       }
+
       if (err ==MISMATCH) break;
     }
   } /*  while (1) */
 
   /* create Scilab variables with each column of data */
   err=Sci_Store(rowcount,ncol,data,type_s,retval_s);
+  Free_Scan(rowcount,ncol,type_s,&data);
   if (err==MEM_LACK) { Scierror(999,"Error: in sscanf: cannot allocate more memory \r\n");}
   return 0;
 } 
@@ -477,34 +501,41 @@ int int_objsscanf(char *fname,unsigned long fname_len)
 
   Nbvars = 0;
   CheckRhs(2,3);
-  if (Rhs==3) {
+
+  if (Rhs==3)
+	{
     GetRhsVar(1,"i",&m1,&n1,&l1);
-    if (m1*n1!=1) {
+    if (m1*n1!=1)
+		{
       Scierror(999,"Error: in sscanf: incorrect first argument\r\n");
       return 0;
     }
+
     iarg=2;
     maxrow=*istk(l1);
-
   }
-  else {
+  else
+	{
     iarg=1;
     maxrow=1;
   }
+
   lw = iarg + Top - Rhs; /* Scilab string vector */
   if (! C2F(getwsmat)("sscanf",&Top,&lw,&m1,&n1,&il1,&ild1,6L)) return 0;
   GetRhsVar(iarg+1,"c",&m2,&n2,&l2); /* Format */
   n_count=StringConvert(cstk(l2))+1;  /* conversion */
-  if (maxrow >= 0) 
-    if (maxrow*n_count>m1*n1) {
-      Scierror(999,"Error: in sscanf: not enough entries in str\r\n");
-      return 0;
-    }
+
+  if ( (maxrow >= 0) && (maxrow*n_count>m1*n1) )
+	{
+		Scierror(999,"Error: in sscanf: not enough entries in str\r\n");
+    return 0;
+  }
 
   k=0;
   nrow=maxrow; 
   rowcount = -1; /* number-1 of result lines already got */
-  while (1) {
+  while (1) 
+	{
     rowcount++;
     if ((maxrow >= 0) && (rowcount >= maxrow)) break;
     if ( k >= m1*n1 ) break;
@@ -516,34 +547,43 @@ int int_objsscanf(char *fname,unsigned long fname_len)
     err = do_scanf("sscanf",(FILE *)0,cstk(l2),&args,str,&retval,buf,type);
     FREE(str);
     if ( err < 0 )  return 0;
-    if ( retval == EOF) {
+
+    if ( retval == EOF) 
+		{
       /* 
-	 first returned argument wil be set to -1 
-	 Scierror(999,"Error: in %s: end of string reached\r\n",fname);
-	 return 0;
+			first returned argument wil be set to -1 
+			Scierror(999,"Error: in %s: end of string reached\r\n",fname);
+			return 0;
       */
     }
-    if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,
-			buf,&data,rowcount,args)) <0 ) {
-      switch (err) {
-      case MISMATCH:
-	if (maxrow>=0) {
-	  Free_Scan(rowcount,ncol,type_s,&data);
-	  Scierror(999,"Error: in sscanf: data mismatch\r\n");
-	  return 0;
-	}
-	break;
-      case MEM_LACK:
-	Free_Scan(rowcount,ncol,type_s,&data);
-	Scierror(999,"Error: in sscanf: cannot allocate more memory \r\n");
-	return 0;
-	break;
+
+    if ((err=Store_Scan(&nrow,&ncol,type_s,type,&retval,&retval_s,buf,&data,rowcount,args)) <0 )
+		{
+      switch (err) 
+			{
+				case MISMATCH:
+					if (maxrow>=0) 
+					{
+						Free_Scan(rowcount,ncol,type_s,&data);
+						Scierror(999,"Error: in sscanf: data mismatch\r\n");
+						return 0;
+					}
+				break;
+
+				case MEM_LACK:
+					Free_Scan(rowcount,ncol,type_s,&data);
+					Scierror(999,"Error: in sscanf: cannot allocate more memory \r\n");
+					return 0;
+				break;
       }
+
       if (err==MISMATCH) break;
     }
   } /* while */
+
   /* create Scilab variables with each column of data */
   err=Sci_Store(rowcount,ncol,data,type_s,retval_s);
+  Free_Scan(rowcount,ncol,type_s,&data);
   if (err==MEM_LACK) { Scierror(999,"Error: in sscanf: cannot allocate more memory \r\n");}
   return 0;
 }
@@ -606,8 +646,7 @@ int int_objfscanf(char *fname,unsigned long fname_len)
     if ( retval == EOF) 
 		{
       /* 
-      Scierror(999,"Error: in %s: end of file reached\r\n",fname);
-
+				Scierror(999,"Error: in %s: end of file reached\r\n",fname);
       */
       break;
     }
@@ -635,9 +674,9 @@ int int_objfscanf(char *fname,unsigned long fname_len)
     }
   } /* while */
 
-
   /* create Scilab variable with each column of data */
   err=Sci_Store(rowcount,ncol,data,type_s,retval_s);
+  Free_Scan(rowcount,ncol,type_s,&data);
   if (err==MEM_LACK) { Scierror(999,"Error: in sscanf: cannot allocate more memory \r\n");}
   return 0;
 }  
@@ -672,44 +711,79 @@ int int_objfprintfMat(char *fname,unsigned long fname_len)
   Nbvars = 0;
   CheckRhs(1,4); 
   CheckLhs(1,1);
-  GetRhsVar(1,"c",&m1,&n1,&l1);/* file name */
-  GetRhsVar(2,"d",&m2,&n2,&l2);/* data */
+
+  if (GetType(1) == sci_strings)
+  {
+	GetRhsVar(1,"c",&m1,&n1,&l1);/* file name */
+  }
+  else
+  {
+	Scierror(999,"first parameter must be a filename.\n");
+	return 0;
+  }
+
+  if (GetType(2) == sci_matrix)
+  {
+	#define COMPLEXPART 1
+	int *header=NULL;
+	int Cmplx;
+
+	header = (int *) GetData(2);
+	Cmplx=header[3];
+
+	if (Cmplx != COMPLEXPART)
+	{
+		GetRhsVar(2,"d",&m2,&n2,&l2); /* data */
+	}
+	else
+	{
+		Scierror(999,"%s works only with reals.\n",fname);
+		return 0;
+	}
+  }
+  else
+  {
+	Scierror(999,"%s works only with reals.\n",fname);
+	return 0;
+  }
+
   if ( Rhs >= 3) 
-    {
-      GetRhsVar(3,"c",&m3,&n3,&l3);/* format */
-      StringConvert(cstk(l3));  /* conversion */
-      Format = cstk(l3);
-    }
+  {
+	GetRhsVar(3,"c",&m3,&n3,&l3);/* format */
+    StringConvert(cstk(l3));  /* conversion */
+    Format = cstk(l3);
+  }
   else 
-    {
-      Format = "%f";
-    }
-  if ( Rhs >= 4 )
-    {
-      GetRhsVar(4,"S",&mS,&nS,&Str2);
-    }
-  if (( f = fopen(cstk(l1),"w")) == (FILE *)0) 
-    {
-      Scierror(999,"Error: in function %s, cannot open file %s\r\n",
-	       fname,cstk(l1));
-      return 0;
-    }
+  {
+    Format = "%f";
+  }
 
   if ( Rhs >= 4 )
-    {
-      for ( i=0 ; i < mS*nS ; i++) 
-	fprintf(f,"%s\n",Str2[i]);
-    }
+  {
+    GetRhsVar(4,"S",&mS,&nS,&Str2);
+  }
+
+  if (( f = fopen(cstk(l1),"w")) == (FILE *)0) 
+  {
+      Scierror(999,"Error: in function %s, cannot open file %s\r\n",fname,cstk(l1));
+      return 0;
+  }
+
+  if ( Rhs >= 4 )
+  {
+		for ( i=0 ; i < mS*nS ; i++) fprintf(f,"%s\n",Str2[i]);
+  }
 
   for (i = 0 ; i < m2 ; i++ ) 
-    {
-      for ( j = 0 ; j < n2 ; j++) 
+  {
+    for ( j = 0 ; j < n2 ; j++) 
 	{
-	  fprintf(f,Format,*stk(l2+i + m2*j));
-	  fprintf(f," ");
+		fprintf(f,Format,*stk(l2+i + m2*j));
+		fprintf(f," ");
 	}
+
       fprintf(f,"\n");
-    }
+  }
   fclose(f);
   LhsVar(1)=0 ; /** no return value **/
   if ( Rhs >= 4) FreeRhsSVar(Str2);
@@ -733,8 +807,10 @@ int int_objfscanfMat(char *fname,unsigned long fname_len)
   int vl=-1;
   FILE  *f;
   char *Format;
-  if ( Info == NULL ) {
-    if (( Info =MALLOC(INFOSIZE*sizeof(char)))==NULL) {
+  if ( Info == NULL )
+	{
+    if (( Info =MALLOC(INFOSIZE*sizeof(char)))==NULL)
+		{
       Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
       return 0;
     }
@@ -745,126 +821,147 @@ int int_objfscanfMat(char *fname,unsigned long fname_len)
   CheckRhs(1,1); /** just 1 **/
   CheckLhs(1,2);
   GetRhsVar(1,"c",&m1,&n1,&l1);/* file name */
+
   if ( Rhs == 2) 
-    {
-      GetRhsVar(2,"c",&m2,&n2,&l2);/* format */
-      StringConvert(cstk(l2));  /* conversion */
-      Format = cstk(l2);
-    }
+  {
+		GetRhsVar(2,"c",&m2,&n2,&l2);/* format */
+    StringConvert(cstk(l2));  /* conversion */
+    Format = cstk(l2);
+  }
   else 
-    {
-      Format = 0;
-    }
+  {
+    Format = 0;
+  }
+
   if (( f = fopen(cstk(l1),"r")) == (FILE *)0) 
-    {
-      Scierror(999,"Error: in function %s, cannot open file %s\r\n",
-	       fname,cstk(l1));
-      return 0;
-    }
+  {
+		Scierror(999,"Error: in function %s, cannot open file %s\r\n",fname,cstk(l1));
+    return 0;
+  }
   /*** first pass to get colums and rows ***/
   strcpy(Info,"--------");
   n =0; 
   while ( sscanf(Info,"%lf",&x) <= 0 && n != EOF ) 
-    { 
-      n=ReadLine(f,&mem); 
-      if ( mem == 1) {
-	FREE(Info);Info=NULL;
-	fclose(f);
-	Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
-	return 0;
-      }
-      vl++;
+  { 
+		n=ReadLine(f,&mem); 
+		if ( mem == 1)
+		{
+			FREE(Info);Info=NULL;
+			fclose(f);
+			Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
+			return 0;
     }
+    vl++;
+  }
+
   if ( n == EOF )
-    {
-      FREE(Info);Info=NULL;
-      fclose(f);
-      Scierror(999,"Error: in function %s, cannot read data in file %s\r\n",
-	       fname,cstk(l1));
-      return 0;
-    }
+	{
+		FREE(Info);Info=NULL;
+    fclose(f);
+    Scierror(999,"Error: in function %s, cannot read data in file %s\r\n",fname,cstk(l1));
+    return 0;
+  }
   cols = NumTokens(Info);
   rows = 1;
+
   while (1) 
-    { 
-      n=ReadLine(f,&mem);
-      if ( mem == 1) {
-	FREE(Info);Info=NULL;
-	fclose(f);
-	Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
-	return 0;
-      }
-      if ( n == EOF ||  n == 0 ) break;
-      if ( sscanf(Info,"%lf",&x) <= 0) break;
-      rows++;
+  { 
+		n=ReadLine(f,&mem);
+    if ( mem == 1)
+		{
+			FREE(Info);Info=NULL;
+			fclose(f);
+			Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
+			return 0;
     }
+
+    if ( n == EOF ||  n == 0 ) break;
+    if ( sscanf(Info,"%lf",&x) <= 0) break;
+    rows++;
+  }
+
   if ( cols == 0 || rows == 0) rows=cols=0;
+
   CreateVar(Rhs+1, "d", &rows, &cols, &lres);
+
   /** second pass to read data **/
   rewind(f);
   /** skip non numeric lines **/
-  if ( Lhs >= 2 && vl != 0 ) {
-    if ((Str = MALLOC((vl+1)*sizeof(char *)))==NULL) {
+
+  if ( Lhs >= 2 && vl != 0 )
+	{
+    if ((Str = MALLOC((vl+1)*sizeof(char *)))==NULL)
+		{
       FREE(Info);Info=NULL;
       fclose(f);
       Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n", fname);
       return 0;
     }
+
     Str[vl]=NULL;
   }
 
   for ( i = 0 ; i < vl ; i++) 
-    {
-      ReadLine(f,&mem);
-      if ( mem == 1) {
-	FREE(Info);Info=NULL;
-	fclose(f);
-	for (j=0;j<i;j++) FREE(Str[j]);
-	FREE(Str);
-	Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
-	return 0;
-      }
-      if ( Lhs >= 2) {
-	if ((Str[i]=MALLOC((strlen(Info)+1)*sizeof(char)))==NULL) { 
-	  FREE(Info);Info=NULL;
-	  fclose(f);
-	  for (j=0;j<i;j++) FREE(Str[j]);
-	  FREE(Str);
-	  Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n", fname);
-	  return 0;
-	}
-	strcpy(Str[i],Info);
-      }
+  {
+		ReadLine(f,&mem);
+    if ( mem == 1)
+		{
+			FREE(Info);Info=NULL;
+			fclose(f);
+			for (j=0;j<i;j++) FREE(Str[j]);
+			FREE(Str);
+			Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n",fname);
+			return 0;
     }
 
-  if ( Lhs >= 2) {
+    if ( Lhs >= 2)
+		{
+			if ((Str[i]=MALLOC((strlen(Info)+1)*sizeof(char)))==NULL)
+			{ 
+				FREE(Info);Info=NULL;
+				fclose(f);
+				for (j=0;j<i;j++) FREE(Str[j]);
+				FREE(Str);
+				Scierror(999,"Error: in function %s, cannot allocate enough memory\r\n", fname);
+				return 0;
+			}
+			strcpy(Str[i],Info);
+    }
+  }
+
+  if ( Lhs >= 2)
+	{
     int un=1,zero=0,l;
+
     if ( vl > 0 ) 
-      {
-	CreateVarFromPtr(Rhs+2,"S",&vl,&un,Str);
-	FreeRhsSVar(Str);
-      }
+    {
+			CreateVarFromPtr(Rhs+2,"S",&vl,&un,Str);
+			FreeRhsSVar(Str);
+    }
     else 
-      {CreateVar(Rhs+2,"c",&zero,&zero,&l);}
+    {
+			CreateVar(Rhs+2,"c",&zero,&zero,&l);
+		}
+
     LhsVar(2)=Rhs+2;
   }
 
-  for (i=0; i < rows ;i++)
-    for (j=0;j < cols;j++)
-      { 
-	double xloc;
-	fscanf(f,"%lf",&xloc);
-	*stk(lres+i+rows*j)=xloc;
-      }
+  for (i=0; i < rows ;i++)for (j=0;j < cols;j++)
+  { 
+		double xloc;
+		fscanf(f,"%lf",&xloc);
+		*stk(lres+i+rows*j)=xloc;
+  }
+
   fclose(f);
   LhsVar(1)=Rhs+1;
   PutLhsVar();
   /* just in case Info is too Big */ 
   if ( Info_size > INFOSIZE ) 
-    {
-      Info_size = INFOSIZE;
-      Info = REALLOC(Info,Info_size*sizeof(char));
-    }
+  {
+		Info_size = INFOSIZE;
+		Info = REALLOC(Info,Info_size*sizeof(char));
+  }
   return 0;
 }  
 /*-----------------------------------------------------------------------------------*/
@@ -911,20 +1008,21 @@ int NumTokens(char *string)
   int n=1;
   int lnchar=0,ntok=-1;
   int length = strlen(string)+1;
+
   if (string != 0)
-    { 
-      /** Counting leading white spaces **/
-      sscanf(string,"%*[ \t\n]%n",&lnchar);
-      while ( n != 0 && n != EOF && lnchar <= length  )
 	{ 
-	  int nchar1=0,nchar2=0;
-	  ntok++;
-	  n= sscanf(&(string[lnchar]),
-		    "%[^ \n\t]%n%*[ \t\n]%n",buf,&nchar1,&nchar2);
-	  lnchar += (nchar2 <= nchar1) ? nchar1 : nchar2 ;
-	}
-      return(ntok);
-    }
+		/** Counting leading white spaces **/
+    sscanf(string,"%*[ \t\n]%n",&lnchar);
+    while ( n != 0 && n != EOF && lnchar <= length  )
+		{ 
+			int nchar1=0,nchar2=0;
+			ntok++;
+			n= sscanf(&(string[lnchar]),"%[^ \n\t]%n%*[ \t\n]%n",buf,&nchar1,&nchar2);
+			lnchar += (nchar2 <= nchar1) ? nchar1 : nchar2 ;
+		}
+
+    return(ntok);
+  }
   return(FAIL);
 }
 /*-----------------------------------------------------------------------------------*/
@@ -949,301 +1047,305 @@ static int do_scanf (char *fname, FILE *fp, char *format, int *nargs, char *strv
   int nc[MAXSCAN];
   int n_directive_count=0;
   char save,directive;
-  char *p,*p1;
+  char *p=NULL,*p1=NULL;
   register char *q;
-  char *target,*sval;
+  char *target=NULL,*sval=NULL;
   int l_flag=0, h_flag=0,width_flag,width_val,ign_flag,str_width_flag=0;
   int num_conversion = -1;	/* for error messages and counting arguments*/
 
-
   PRINTER printer;		/* pts at fprintf() or sprintf() */
   if (fp == (FILE *) 0)		
-    {
-      /* doing sscanf or scanf */
-      target = strv;
-      printer = (PRINTER) sscanf;
-    }
+  {
+     /* doing sscanf or scanf */
+     target = strv;
+     printer = (PRINTER) sscanf;
+  }
   else
-    {
-      /* doing fscanf */
-      target = (char *) fp;
-      printer = (PRINTER) fscanf;
-    }
+  {
+     /* doing fscanf */
+     target = (char *) fp;
+     printer = (PRINTER) fscanf;
+  }
   
   q = format;
   *retval = 0;
 
   /* Traverse format string, doing scanf(). */
   while (1)
-    {
-      /* scanf */
-      p=q;
-      while (*q != '%' && *q != '\0' ) q++;
-      if ( *q == '%' && *(q+1) == '%' ) 
-	{
-	  q=q+2;
-	  while (*q != '%' && *q != '\0' ) q++;
-	}
-      if (*q == 0) 
-	{
-	  break ;
-	}
+  {
+    /* scanf */
+    p=q;
+    while (*q != '%' && *q != '\0' ) q++;
+    if ( *q == '%' && *(q+1) == '%' ) 
+		{
+			q=q+2;
+			while (*q != '%' && *q != '\0' ) q++;
+		}
 
-      q++; /** q point to character following % **/
+    if (*q == 0) 
+		{
+			break ;
+		}
+
+    q++; /** q point to character following % **/
 
       
-      /* 
-       * We have found a conversion specifier, figure it out,
-       * then scan the data asociated with it.
-       */
+    /* 
+     * We have found a conversion specifier, figure it out,
+     * then scan the data asociated with it.
+    */
 
 
-      /* mark the '%' with p1 */
-      
-      p1 = q - 1; 
+    /* mark the '%' with p1 */
+    p1 = q - 1; 
 
-      /* check for width field */
+    /* check for width field */
 
-      while ( isdigit(((int)*q)) ) q++;
-      width_flag =0;
+    while ( isdigit(((int)*q)) ) q++;
 
-      if ( p1+1 != q ) 
-	{	  
-	  char w= *q;
-	  *q='\0';
-	  width_flag = 1;
-	  sscanf(p1+1,"%d",&width_val);
-	  *q=w;
-	}
+    width_flag =0;
 
-      /* check for ignore argument */
+    if ( p1+1 != q ) 
+		{	  
+			char w= *q;
+			*q='\0';
+			width_flag = 1;
+			sscanf(p1+1,"%d",&width_val);
+			*q=w;
+		}
 
-      ign_flag=0;
+    /* check for ignore argument */
 
-      if (*q == '*')
-	{
-	  /* Ignore the argument in the input args */
-	  /*num_conversion = Max(num_conversion-1,0);*/
-	  ign_flag = 1;
-	  q++;
-	}
-      else
+    ign_flag=0;
 
-      /* check for %l or %h */
+    if (*q == '*')
+		{
+			/* Ignore the argument in the input args */
+			/*num_conversion = Max(num_conversion-1,0);*/
+			ign_flag = 1;
+			q++;
+		}
+    else
+		{
+			/* check for %l or %h */
+			l_flag = h_flag = 0;
+		}
+    
 
-      l_flag = h_flag = 0;
+    if (*q == 'l')
+		{
+			q++;
+			l_flag = 1;
+		}
+    else if (*q == 'h')
+		{
+			q++;
+			h_flag = 1;
+		}
 
-      if (*q == 'l')
-	{
-	  q++;
-	  l_flag = 1;
-	}
-      else if (*q == 'h')
-	{
-	  q++;
-	  h_flag = 1;
-	}
+    /* directive points to the scan directive  */
 
-      /* directive points to the scan directive  */
+    directive = *q++;
 
-      directive = *q++;
+    if ( directive == '[' )
+		{
+			char *q1=q--;
+			/** we must find the closing bracket **/
+			while ( *q1 != '\0' && *q1 != ']') q1++;
 
-      if ( directive == '[' )
-	{
-	  char *q1=q--;
-	  /** we must find the closing bracket **/
-	  while ( *q1 != '\0' && *q1 != ']') q1++;
-	  if ( *q1 == '\0') 
+			if ( *q1 == '\0') 
 	    {
-	      Scierror(998,"Error:\tscanf, unclosed [ directive\r\n");
+				Scierror(998,"Error:\tscanf, unclosed [ directive\r\n");
 	      return RET_BUG;
 	    }
-	  if ( q1 == q +1 || strncmp(q,"[^]",3)==0 ) 
+
+			if ( q1 == q +1 || strncmp(q,"[^]",3)==0 ) 
 	    {
 	      q1++;
 	      while ( *q1 != '\0' && *q1 != ']') q1++;  
-	      if ( *q1 == '\0') 
-		{
-		  Scierror(998,"Error:\tscanf unclosed [ directive\r\n");
-		  return RET_BUG;
-		}
-	    }
-	  directive = *q1++;
-	  q=q1;
-	}
 
-      /** accumulate characters in the format up to next % directive **/
-      /*** unused 
-      while ( *q != '\0' && *q != '%' ) q++;
-      if ( *q == '%' && *(q+1) == '%' ) 
-	{
-	  q=q+2;
-	  while (*q != '%' && *q != '\0' ) q++;
-	}
-	**/
-      save = *q;
-      /* *q = 0; */
-      
-      /** if (debug) Sciprintf("Now directive [%s],%c\r\n",p,directive); **/
-      
-      if ( ign_flag != 1) 
-	{
-	  num_conversion++;
-	  if ( num_conversion > MAXSCAN ) 
+	      if ( *q1 == '\0') 
+				{
+					Scierror(998,"Error:\tscanf unclosed [ directive\r\n");
+					return RET_BUG;
+				}
+	    }
+
+			directive = *q1++;
+			q=q1;
+		}
+
+    save = *q;
+         
+    if ( ign_flag != 1) 
+		{
+			num_conversion++;
+
+			if ( num_conversion >= MAXSCAN ) 
 	    {
-	      Scierror(998,"Error:\tscanf too many (%d > %d) conversion required\r\n",
-		       num_conversion,MAXSCAN);
+	      Scierror(998,"Error:\tscanf too many (> %d) conversion required\r\n",num_conversion,MAXSCAN);
 	      return RET_BUG;
 	    }
-	  switch (directive )
+
+			switch (directive )
 	    {
-	    case ']':
-	      if (width_flag == 0 ) str_width_flag = 1;
-	      if (width_flag == 1 && width_val > MAX_STR-1 )
-		{
-		  Scierror(998,"Error:\tscanf, width field %d is too long (> %d) for %%[ directive\r\n",
-			   width_val,MAX_STR-1);
-		  return RET_BUG;
-		}
-	      if ((buf[num_conversion].c=MALLOC(MAX_STR))==NULL) return MEM_LACK;
-	      ptrtab[num_conversion] =  buf[num_conversion].c;
-	      type[num_conversion] = SF_S;
+				case ']':
+					if (width_flag == 0 ) str_width_flag = 1;
+
+					if (width_flag == 1 && width_val > MAX_STR-1 )
+					{
+						Scierror(998,"Error:\tscanf, width field %d is too long (> %d) for %%[ directive\r\n",width_val,MAX_STR-1);
+						return RET_BUG;
+					}
+
+					if ((buf[num_conversion].c=MALLOC(MAX_STR))==NULL) return MEM_LACK;
+					ptrtab[num_conversion] =  buf[num_conversion].c;
+					type[num_conversion] = SF_S;
 	      break;
-	    case 's':
-	      if (l_flag + h_flag) {
-		Scierror(998,"Error:\tscanf: bad conversion\r\n");
-		return RET_BUG;
-	      }
-	      if (width_flag == 0 ) str_width_flag = 1;
-	      if (width_flag == 1 && width_val > MAX_STR-1 )
-		{
-		  Scierror(998,"Error:\tscanf, width field %d is too long (< %d) for %%s directive\r\n",
-			   width_val,MAX_STR-1);
-		  return RET_BUG;
-		}
-	      if ((buf[num_conversion].c=MALLOC(MAX_STR))==NULL) return MEM_LACK;
-	      ptrtab[num_conversion] =  buf[num_conversion].c;
-	      type[num_conversion] = SF_S;
+
+				case 's':
+					if (l_flag + h_flag)
+					{
+						Scierror(998,"Error:\tscanf: bad conversion\r\n");
+						return RET_BUG;
+					}
+
+					if (width_flag == 0 ) str_width_flag = 1;
+					if (width_flag == 1 && width_val > MAX_STR-1 )
+					{
+						Scierror(998,"Error:\tscanf, width field %d is too long (< %d) for %%s directive\r\n",width_val,MAX_STR-1);
+						return RET_BUG;
+					}
+
+					if ((buf[num_conversion].c=MALLOC(MAX_STR))==NULL) return MEM_LACK;
+
+					ptrtab[num_conversion] =  buf[num_conversion].c;
+					type[num_conversion] = SF_S;
 	      break;
-	    case 'c':
-	      if (l_flag + h_flag) {
-		Scierror(998,"Error:\tscanf: bad conversion\r\n");
-		return RET_BUG;
-	      }
-	      if ( width_flag == 1 ) 
-		nc[num_conversion ] = width_val;
-	      else
-		nc[num_conversion ] = 1;
-	      if (width_flag == 1 && width_val > MAX_STR-1 )
-		{
-		  Scierror(998,"Error:\tscanf width field %d is too long (< %d) for %%c directive\r\n",
-			   width_val,MAX_STR-1);
-		  return RET_BUG;
-		}
-	      if ((buf[num_conversion].c=MALLOC(MAX_STR))==NULL) return MEM_LACK;
-	      ptrtab[num_conversion] =  buf[num_conversion].c;
-	      type[num_conversion] = SF_C;
+
+				case 'c':
+					if (l_flag + h_flag)
+					{
+						Scierror(998,"Error:\tscanf: bad conversion\r\n");
+						return RET_BUG;
+					}
+
+					if ( width_flag == 1 ) nc[num_conversion ] = width_val;
+					else nc[num_conversion ] = 1;
+
+					if (width_flag == 1 && width_val > MAX_STR-1 )
+					{
+						Scierror(998,"Error:\tscanf width field %d is too long (< %d) for %%c directive\r\n",width_val,MAX_STR-1);
+						return RET_BUG;
+					}
+
+					if ((buf[num_conversion].c=MALLOC(MAX_STR))==NULL) return MEM_LACK;
+
+					ptrtab[num_conversion] =  buf[num_conversion].c;
+					type[num_conversion] = SF_C;
 	      break;
-	    case 'o':
-	    case 'u':
-	    case 'x':
-	    case 'X':
-	      if ( l_flag ) 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].lui;
-		  type[num_conversion] = SF_LUI;
-		}
-	      else if ( h_flag) 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].sui;
-		  type[num_conversion] = SF_SUI;
-		}
-	      else 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].ui;
-		  type[num_conversion] = SF_UI;
-		}
+
+				case 'o': case 'u': case 'x': case 'X':
+					if ( l_flag ) 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].lui;
+						type[num_conversion] = SF_LUI;
+					}
+					else if ( h_flag) 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].sui;
+						type[num_conversion] = SF_SUI;
+					}
+					else 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].ui;
+						type[num_conversion] = SF_UI;
+					}
 	      break;
-	    case 'D':
-	      ptrtab[num_conversion] =  &buf[num_conversion].li;
-	      type[num_conversion] = SF_LI;
+
+				case 'D':
+					ptrtab[num_conversion] =  &buf[num_conversion].li;
+					type[num_conversion] = SF_LI;
 	      break;
-	    case 'n':
-	      /** count the n directives since they are not counted by retval **/
-	      n_directive_count++;
-	    case 'i':
-	    case 'd':
-	      if ( l_flag ) 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].li;
-		  type[num_conversion] = SF_LI;
-		}
-	      else if ( h_flag) 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].si;
-		  type[num_conversion] = SF_SI;
-		}
-	      else 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].i;
-		  type[num_conversion] = SF_I;
-		}
-	      break;
-	    case 'e':
-	    case 'f':
-	    case 'g':
-	    case 'E':
-	    case 'G':
-	      if (h_flag)
-		{
-		  Scierror(998,"Error:\tscanf: bad conversion\r\n");
-		  return RET_BUG;
-		}
-	      else if (l_flag) 
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].lf;
-		  type[num_conversion] = SF_LF;
-		}
-	      else
-		{
-		  ptrtab[num_conversion] =  &buf[num_conversion].f;
-		  type[num_conversion] = SF_F;
-		}
-	      break;
-	    default:
-	      Scierror(998,"Error:\tscanf: bad conversion\r\n");
-	      return RET_BUG;
+
+				case 'n':
+					/** count the n directives since they are not counted by retval **/
+					n_directive_count++;
+
+				case 'i': case 'd':
+					if ( l_flag ) 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].li;
+						type[num_conversion] = SF_LI;
+					}
+					else if ( h_flag) 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].si;
+						type[num_conversion] = SF_SI;
+					}
+					else 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].i;
+						type[num_conversion] = SF_I;
+					}
+				break;
+
+				case 'e': case 'f': case 'g': case 'E': case 'G':
+					if (h_flag)
+					{
+						Scierror(998,"Error:\tscanf: bad conversion\r\n");
+						return RET_BUG;
+					}
+					else if (l_flag) 
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].lf;
+						type[num_conversion] = SF_LF;
+					}
+					else
+					{
+						ptrtab[num_conversion] =  &buf[num_conversion].f;
+						type[num_conversion] = SF_F;
+					}
+				break;
+
+				default:
+					Scierror(998,"Error:\tscanf: bad conversion\r\n");
+					return RET_BUG;
+				break;
 	    }
-	  *q = save;
-	}
-    }
+			*q = save;
+		}
+  }
   /** we replace %s and %[ directive with a max length field **/
   
   if ( str_width_flag == 1) 
-    {
-      char *f1=format;
-      char *f2=sformat;
-      char *slast = sformat + MAX_STR-1 -4;
-      while ( *f1 != '\0'  ) 
-	{
-	  int n;
-	  *f2++ = *f1++;
+  {
+    char *f1=format;
+    char *f2=sformat;
+    char *slast = sformat + MAX_STR-1 -4;
+
+    while ( *f1 != '\0'  ) 
+		{
+			int n;
+			*f2++ = *f1++;
 	  
-	  if ( *(f1-1) == '%' && ( *(f1) == 's'  || *(f1) == '['))
+			if ( *(f1-1) == '%' && ( *(f1) == 's'  || *(f1) == '['))
 	    {
-	      n=sprintf(f2,"%d",MAX_STR-1);
+				n=sprintf(f2,"%d",MAX_STR-1);
 	      f2 += n;
-      	      *f2++ = *f1++;
+      	*f2++ = *f1++;
 	    }
-	  if ( f2 == slast )
+
+			if ( f2 == slast )
 	    {
 	      Scierror(998,"Error:\tscanf, format is too long (> %d) \r\n",MAX_STR-1);
 	      return RET_BUG;
 	    }
-	}
-      *f2='\0';
-      format = sformat;
-    }
+		}
+
+		*f2='\0';
+		format = sformat;
+  }
     
 
   /** Calling scanf function : 
@@ -1251,20 +1353,25 @@ static int do_scanf (char *fname, FILE *fp, char *format, int *nargs, char *strv
     the last arguments transmited points to nothing 
     but this is not a problem since they won't be used ***/
 
+*retval = (*printer) ((VPTR) target,format,
+ptrtab[0],ptrtab[1],ptrtab[2],ptrtab[3],ptrtab[4],ptrtab[5],ptrtab[6],ptrtab[7],ptrtab[8],ptrtab[9],
+ptrtab[10],ptrtab[11],ptrtab[12],ptrtab[13],ptrtab[14],ptrtab[15],ptrtab[16],ptrtab[17],ptrtab[18],ptrtab[19],
+ptrtab[20],ptrtab[21],ptrtab[22],ptrtab[23],ptrtab[24],ptrtab[25],ptrtab[26],ptrtab[27],ptrtab[28],ptrtab[29],
+ptrtab[30],ptrtab[31],ptrtab[32],ptrtab[33],ptrtab[34],ptrtab[35],ptrtab[36],ptrtab[37],ptrtab[38],ptrtab[39],
+ptrtab[40],ptrtab[41],ptrtab[42],ptrtab[43],ptrtab[44],ptrtab[45],ptrtab[46],ptrtab[47],ptrtab[48],ptrtab[49],
+ptrtab[50],ptrtab[51],ptrtab[52],ptrtab[53],ptrtab[54],ptrtab[55],ptrtab[56],ptrtab[57],ptrtab[58],ptrtab[59],
+ptrtab[60],ptrtab[61],ptrtab[62],ptrtab[63],ptrtab[64],ptrtab[65],ptrtab[66],ptrtab[67],ptrtab[68],ptrtab[69],
+ptrtab[70],ptrtab[71],ptrtab[72],ptrtab[73],ptrtab[74],ptrtab[75],ptrtab[76],ptrtab[77],ptrtab[78],ptrtab[79],
+ptrtab[80],ptrtab[81],ptrtab[82],ptrtab[83],ptrtab[84],ptrtab[85],ptrtab[86],ptrtab[87],ptrtab[88],ptrtab[89],
+ptrtab[90],ptrtab[91],ptrtab[92],ptrtab[93],ptrtab[94],ptrtab[95],ptrtab[96],ptrtab[97],ptrtab[98],ptrtab[MAXSCAN-1]);
 
-  *retval = (*printer) ((VPTR) target,format,ptrtab[0],ptrtab[1],ptrtab[2],
-			ptrtab[3],ptrtab[4],ptrtab[5],ptrtab[6],ptrtab[7],
-			ptrtab[8],ptrtab[9],ptrtab[10],ptrtab[11],ptrtab[12],
-			ptrtab[13],ptrtab[14],ptrtab[15],ptrtab[16],ptrtab[17],
-			ptrtab[18],ptrtab[19],ptrtab[20],ptrtab[21],ptrtab[22],
-			ptrtab[23],ptrtab[24],ptrtab[25],ptrtab[26],ptrtab[27],
-			ptrtab[28],ptrtab[29]);
-  /** *nargs counts the number of corectly scaned arguments **/
+	/** *nargs counts the number of crorectly scaned arguments **/
   *nargs = Min(num_conversion+1,Max(*retval+n_directive_count,0));
 
   for ( i=1 ; i <= *nargs ; i++) 
-    if ( type[i-1]  == SF_C ) {
-      sval=(char *) ptrtab[i-1];
+    if ( type[i-1]  == SF_C )
+		{
+			sval=(char *) ptrtab[i-1];
       sval[nc[i-1]]='\0';
     }
   return 0;
@@ -1818,7 +1925,7 @@ static int Sci_Store(int nrow, int ncol, entry *data, sfdir *type, int retval_s)
 	for (j=0;j<nrow;j++) temp[k++]=data[i+ncol*j].s;
 	CreateVarFromPtr(++iarg, "S", &nrow, &one, temp);
 	FREE(temp);
-	for (j=0;j<nrow;j++) FREE(data[i+ncol*j].s);
+	/*	for (j=0;j<nrow;j++) FREE(data[i+ncol*j].s);*/
       }
       else {
 	CreateVar(++iarg, "d", &nrow, &one, &l);
@@ -1828,7 +1935,7 @@ static int Sci_Store(int nrow, int ncol, entry *data, sfdir *type, int retval_s)
 
       LhsVar(i+2)=iarg;
     }
-    FREE(data);
+    /*FREE(data);*/
     /** we must complete the returned arguments up to Lhs **/
   Complete:
     for ( i = ncol+2; i <= Lhs ; i++) 
@@ -1872,8 +1979,8 @@ static int Sci_Store(int nrow, int ncol, entry *data, sfdir *type, int retval_s)
 	      for (j=0;j<nrow;j++) temp[k++]=data[i1+ncol*j].s;
 	    CreateVarFromPtr(++iarg, "S", &nrow, &colcount,temp);
 	    FREE(temp);
-	    for (i1=cur_i;i1<i;i1++)
-	      for (j=0;j<nrow;j++) FREE(data[i1+ncol*j].s);
+	    /*	    for (i1=cur_i;i1<i;i1++)
+		    for (j=0;j<nrow;j++) FREE(data[i1+ncol*j].s);*/
 	  }
 	  else {
 	    CreateVar(++iarg, "d", &nrow, &colcount, &l);
@@ -1908,8 +2015,8 @@ static int Sci_Store(int nrow, int ncol, entry *data, sfdir *type, int retval_s)
 	  for (j=0;j<nrow;j++) temp[k++]=data[i1+ncol*j].s;
 	CreateVarFromPtr(Rhs+1, "S", &nrow, &ncol, temp);
 	FREE(temp);
-	for (i1=0;i1<ncol;i1++)
-	  for (j=0;j<nrow;j++) FREE(data[i1+ncol*j].s);
+	/*for (i1=0;i1<ncol;i1++)
+	  for (j=0;j<nrow;j++) FREE(data[i1+ncol*j].s);*/
       }
       else {
 	CreateVar(Rhs+1, "d", &nrow, &ncol, &l);
