@@ -399,6 +399,7 @@ DestroyLegend (sciPointObj * pthis)
   sciLegend * ppLegend = pLEGEND_FEATURE (pthis) ;
   FREE(ppLegend->pptabofpointobj);
   FREE (ppLegend->text.ptextstring);
+  FREE( ppLegend->pstyle ) ;
   FREE (ppLegend->user_data);
   ppLegend->size_of_user_data = 0;
 
@@ -421,7 +422,6 @@ DestroyLegend (sciPointObj * pthis)
 int
 DestroyPolyline (sciPointObj * pthis)
 {
-  FREE (pPOLYLINE_FEATURE (pthis)->pvector);
   FREE (pPOLYLINE_FEATURE (pthis)->pvx);
   FREE (pPOLYLINE_FEATURE (pthis)->pvy);
   FREE (pPOLYLINE_FEATURE (pthis)->user_data);
@@ -507,20 +507,26 @@ DestroySurface (sciPointObj * pthis)
   sciDelThisToItsParent (pthis, sciGetParent (pthis));
   if (sciDelHandle (pthis) == -1)
     return -1;
-  /*FREE (pSURFACE_FEATURE (pthis)->pproj);*/
+
   FREE (sciGetPointerToFeature (pthis));
   FREE (pthis);
   cmpt=0;
   psonstmp = sciGetSons (psubwin);
   while (psonstmp != (sciSons *) NULL)	
     {   
-      if(sciGetEntityType (psonstmp->pointobj) == SCI_SURFACE) 
+      if(sciGetEntityType (psonstmp->pointobj) == SCI_SURFACE)
+      {
 	cmpt=cmpt+1;
+      }
       psonstmp = psonstmp->pnext;
     }
-  if (cmpt < 2){
+  if (cmpt < 2)
+  {
     if ((pobj= sciGetMerge(psubwin)) != (sciPointObj *) NULL)
-      DestroyMerge(pobj); 
+    {
+      DestroyMerge(pobj);
+      
+    }
   }
   else
     Merge3d(psubwin);
@@ -886,5 +892,30 @@ void delete_sgwin_entities(int win_num,int v_flag)
 	  }
     }
 }
-
-
+/*------------------------------------------------------------------------------------*/
+/**
+ * Update the merge object of a subwindow. If there is not anymore surface in the descendants
+ * then object is cleared. Otherwise a new merge3d is created. This function should be called
+ * after a modifications of the graphic hierarchy related with surfaces.
+ * @return 0 if the call was successful, -1 otherwise.
+ */
+int updateMerge( sciPointObj * pSubwin )
+{
+  if ( sciGetNbTypedObjects( pSubwin, SCI_SURFACE ) == 0 )
+  {
+    sciPointObj * merge = sciGetMerge( pSubwin ) ;
+    if ( merge != NULL )
+    {
+      DestroyMerge( merge ) ;
+    }
+    pSUBWIN_FEATURE( pSubwin )->facetmerge = FALSE ;
+  }
+  else
+  {
+    /* the merge 3d is updated */
+    Merge3d( pSubwin ) ;
+    pSUBWIN_FEATURE( pSubwin )->facetmerge = TRUE ;
+  }
+  return 0 ;
+}
+/*-----------------------------------------------------------------------------------------*/
