@@ -56,6 +56,7 @@
 #define SB_HORZ 0
 #endif 
 #define NUMCOLORS_SCI 32
+#define SCI_FIGURE_NAME_LENGTH 256
 /* Renvoi le pointeur sur la structure */
 
 #define pFIGURE_FEATURE(pointobj)      ((sciFigure        *)pointobj->pfeatures)/** */
@@ -438,7 +439,7 @@ typedef struct
   sciGraphicContext graphiccontext; /* the only property used here is background */
   sciPointObj * originalsubwin0011;
   /** specifies the title for this window  */
-  char name[80];	 
+  char name[SCI_FIGURE_NAME_LENGTH];	 
   /** specifies le length of the string name */
   int namelen;
   /** specifies the number of this window            */
@@ -513,9 +514,9 @@ typedef struct
   int callbackevent; 
   /** specifies if this object is visble             */
   BOOL visible;
-  int isclip;
-  double clip_region[4];
-  int clip_region_set;
+  int isclip; /* this is the scilab clip_state propety */
+  double clip_region[4]; /* scilab clip_box property */
+  int clip_region_set; /* false if the clip state of the object has not already been set */
   
   int * user_data; /* adding 27.06.05 */
   int size_of_user_data;
@@ -896,7 +897,6 @@ typedef struct
 {
   sciRelationShip relationship;
   sciGraphicContext graphiccontext;
-  POINT2D *pvector;		/* vecteur de points redondant, for future developpement*/
   double *pvx;			/* vecteur des points x doublon avec pvector je les garde pour compatiblite*/
   double *pvy;			/* vecteur des points y doublon avec pvector*/
   double *pvz; /**DJ.Abdemouche 2003**/
@@ -1015,7 +1015,6 @@ typedef struct
   int m3,n3;
   int m3n,n3n;
 
-  POINT2D *pproj;			/* projections on 2d */
   integer flag[3];
   double ebox[6];
   int flagcolor; /* this flag indicates the type of the color of how the facet have to be colored 
@@ -1176,16 +1175,16 @@ typedef struct
   sciGraphicContext graphiccontext; 
   double *vx;  /** vx vector of size Nbr **/ /*F.Leray 18.02.04 ...of size Nbr1 ? No depending on the type ptype*/
   double *vy;  /** vy vector of size Nbr **/ /*F.Leray 18.02.04 ...of size Nbr2 ? No depending on the type ptype*/
-  double *vfx;
-  double *vfy;
-  integer Nbr1;   
-  integer Nbr2;
+  double *vfx; /**< size Nbr1 * Nbr2 */
+  double *vfy; /**< size Nbr1 * Nbr2 */
+  integer Nbr1; /**< size of vx and vy id segs handle, or size of vx if champ */ 
+  integer Nbr2; /**< size of vy if champ handle */
   integer *pstyle;
   integer iflag;      /**0 or 1, flag which control the drawing of the segment  **/
   double arrowsize;  /*F.Leray units : hundreds (i.e. 100, 150,...)*/
   double parfact;
   integer ptype; /* if ptype=0, it is segments; if ptype=1, it is champ (champ or champ1)*/
-  integer typeofchamp; /* when ptype=0, if typeofchamp=0 => champ is invoked else champ1 is invoked (typeofchamp==1) */
+  integer typeofchamp; /**< when ptype=0, if typeofchamp=0 => champ is invoked else champ1 is invoked (typeofchamp==1) */
   BOOL isselected;
   char *callback; /** specifies the text scilab code for the callback associated with this entity */
   int callbacklen; /** the length of the callback code */  
