@@ -4,6 +4,10 @@
  *    jpc@cereve.enpc.fr 
  --------------------------------------------------------------------------*/
 
+#ifndef __PERIWIN_H__
+#define __PERIWIN_H__
+
+
  extern void C2F(drawarc)();
  extern void C2F(fillarcs)();
  extern void C2F(drawarcs)();
@@ -39,6 +43,7 @@
  extern void C2F(loadfamily)();
  extern void  C2F(queryfamily)();
  extern void C2F(xinfo)();
-
+ 
+#endif /* __PERIWIN_H__ */
 
 
