@@ -1,22 +1,19 @@
       subroutine i_maxi()
 c     -------------------------------
-c     maxi mini interface 
+c     max interface 
+c     Author: Serge Steer, Copyright INRIA
 c     -------------------------------
-      character*(2) type
-c     Interface for maxi and mini 
       INCLUDE '../stack.h'
-      logical checkrhs,checklhs,getsmat
-      integer gettype,itype,topk
+      logical checkrhs,checklhs
+      integer gettype,itype,topk,sel
       integer iadr,sadr
-      external memused,uppertype
-      integer memused,uppertype
+      external memused,uppertype, mtlbsel
+      integer memused,uppertype, mtlbsel
       double precision s
 c
       iadr(l)=l+l-1
       sadr(l)=(l/2)+1
 c
-      type='g'//char(0)
-
       topk=top
       if (.not.checklhs(fname,1,2)) return
       if (rhs.le.0) then 
@@ -24,39 +21,37 @@ c
          return
       endif
       itype=gettype(topk)
-
       if(rhs.gt.1.and.itype.ne.10) goto 100
 c
 
 c     maxi(A1)
- 10   if(rhs.eq.2) then 
-         if(.not.getsmat(fname,topk,top,m2,n2,1,1,lr2,nlr2))return
-         if (nlr2.ne.1) then
-            buf='max : second argument must be "c" or "r"'
-            call error(999)         
-            return
-         endif
-         call cvstr(nlr2,istk(lr2),type,1)
+
+ 10   sel=0
+      if(rhs.eq.2) then 
+         call  getorient(topk,sel)
+         if(err.gt.0) return
          top=top-1
       endif
+
       lw=iadr(lstk(top+1))
 c
       il=iadr(lstk(top))
+      if(sel.eq.-1) sel=mtlbsel(istk(il+1),2)
       m=istk(il+1)
       n=istk(il+2)
       it=istk(il+3)
       lr1=il+4
 
-      if ( type(1:1).eq.'r') then 
+      if (sel.eq.1) then 
 c     ------------max of each column of a 
          mr=1
          nr=n
          job=1
-      elseif( type(1:1).eq.'c') then    
+      elseif(sel.eq.2) then    
          mr=m
          nr=1
          job=2
-      elseif( type(1:1).eq.'g') then    
+      else
          mr=1
          nr=1
          job=0
@@ -78,18 +73,39 @@ c     ------------max of each column of a
       if(lhs.eq.2) then
          top=top+1
          ilk=iadr(lstk(top))
-
          l=sadr(ilk+4)
-         if(ilk+4.gt.lk) then
-            call int2db(mnr,istk(lk),-1,stk(l),-1)
+         if (job.ne.0) then
+            if(ilk+4.ge.lk) then
+               call int2db(mnr,istk(lk),-1,stk(l),-1)
+            else
+               call int2db(mnr,istk(lk),1,stk(l),1)
+            endif
+            istk(ilk)=1
+            istk(ilk+1)=mr
+            istk(ilk+2)=nr
+            istk(ilk+3)=0
+            lstk(top+1)=l+mnr
          else
-            call int2db(mnr,istk(lk),1,stk(l),1)
+           k=istk(lk)
+           kc=k/m
+           kl=k-kc*m
+           if(kl.eq.0) then 
+              kc=kc-1
+              kl=m
+           endif
+           err=l+2-lstk(bot)
+           if(err.gt.0) then
+              call error(17)
+              return
+           endif
+            istk(ilk)=1
+            istk(ilk+1)=1
+            istk(ilk+2)=2
+            istk(ilk+3)=0
+            lstk(top+1)=l+2
+            stk(l)=kl
+            stk(l+1)=kc+1
          endif
-         istk(ilk)=1
-         istk(ilk+1)=mr
-         istk(ilk+2)=nr
-         istk(ilk+3)=0
-         lstk(top+1)=l+mnr
       endif
       return
 
