@@ -3,7 +3,7 @@ c ====================================================================
 C     dasrt 
 c ====================================================================
 c
-c     Copyright INRIA
+c     Copyright INRIA/ENPC 
       INCLUDE '../stack.h'
 c
       character*(*) fname
@@ -38,7 +38,7 @@ c     [,hotdata])
       topw=top+1
       lw = lstk(topw)
       l0 = lstk(top+1-rhs)
-      if (.not.checkrhs(fname,7,11)) return
+      if (.not.checkrhs(fname,6,11)) return
       if (.not.checklhs(fname,2,3)) return
 c     checking variable y0 (number 1)
 c     -------------------------------
@@ -119,17 +119,28 @@ c     --------------------------------
 c     checking variable number 7
 c     -----------------------------
       kjac=top-rhs+7-iskip
-      is7 = gettype(kjac)
-c     if(kjac.eq.top.or.
-c     $     kjac.eq.top-1.and.istk(iadr(lstk(top))).eq.1) then
-      if((is7.ne.11).and.(is7.ne.13).and.
-     $     (is7.ne.10).and.(is7.ne.15)) then
+      if(kjac.gt.top) then
          iskip=iskip+1
          info(5)=0
       else
-         info(5)=1
-         if (.not.getexternal(fname,topk,kjac,namej,type,
-     $        setfjacd)) return
+         is7 = gettype(kjac)
+         if(is7.eq.15) then
+c     .     info or jac ? get list size to decide
+            il7=iadr(lstk(kjac))
+            if (istk(il7).lt.0)  il7=istk(il7+1)
+            if (istk(il7+1).eq.2) then
+c     .        jac
+               is7=13
+            endif
+         endif
+         if((is7.ne.10).and.(is7.ne.11).and.(is7.ne.13)) then
+            iskip=iskip+1
+            info(5)=0
+         else
+            info(5)=1
+            if (.not.getexternal(fname,topk,kjac,namej,type,
+     $           setfjacd)) return
+         endif
       endif
 c     DASRT nh,h
 c     checking variable number 8
@@ -143,11 +154,30 @@ c     checking variable number 9
 c     
 c     checking variable info (number 10)
 c     ------------------------------------
+      kinfo = top-rhs+10-iskip
+      if (kinfo.gt.top) then
+         info(4)=0
+         info(3)=0
+         info(6)=0
+         info(7)=0
+         info(8)=0
+         info(10)=0
+         info(11)=0
+         iskip=iskip+1
+         goto 10
+      endif
       il10 = iadr(lstk(top-rhs+10-iskip))
       if (istk(il10) .ne. 15) then
-         err = 10-iskip
-         call error(56)
-         return
+c     default info values
+         info(4)=0
+         info(3)=0
+         info(6)=0
+         info(7)=0
+         info(8)=0
+         info(10)=0
+         info(11)=0
+         iskip=iskip+1
+         goto 10
       endif
       n10=istk(il10+1)
       l10=sadr(il10+n10+3)
@@ -222,7 +252,7 @@ c     --   subvariable isest(info) --
       if(isest.eq.1) info(11)=1
       
       
-      hotstart=.false.
+ 10   hotstart=.false.
       if(rhs.eq.11-iskip) then
          hotstart=.true.
 c     
@@ -345,16 +375,16 @@ c     not enough memory
          endif
          if (tout .eq. t0) then
             stk(lyri)=tout
-            call dcopy(n1,stk(l1),1,stk(lyri+1),1)
-            call dcopy(n1,stk(lydot),1,stk(lyri+n1+1),1)
+            call unsfdcopy(n1,stk(l1),1,stk(lyri+1),1)
+            call unsfdcopy(n1,stk(lydot),1,stk(lyri+n1+1),1)
             l1=lyri+1
             lydot=lyri+n1+1
             t0=tout
             goto 1120            
          else
             stk(lyri)=tout
-            call dcopy(n1,stk(l1),1,stk(lyri+1),1)
-            call dcopy(n1,stk(lydot),1,stk(lyri+n1+1),1)
+            call unsfdcopy(n1,stk(l1),1,stk(lyri+1),1)
+            call unsfdcopy(n1,stk(lydot),1,stk(lyri+n1+1),1)
             l1=lyri+1
             lydot=lyri+n1+1
             call ddasrt(bresd,n1,t0,stk(l1),stk(lydot),
@@ -515,13 +545,13 @@ c
       istk(ilw+2)=1
       istk(ilw+3)=0
       lw=sadr(ilw+4)
-      call dcopy(lrw,stk(lrwork),1,stk(lw),1)
+      call unsfdcopy(lrw,stk(lrwork),1,stk(lw),1)
       call int2db(liw,istk(iadr(liwork)),1,stk(lw+lrw),1)
       lw=lw+lrw+liw
       lstk(top+1)=lw-mv
 c     
 c     Remise en place de la pile
- 1150 call dcopy(lw-lw0,stk(lw0),1,stk(l0),1)      
+ 1150 call unsfdcopy(lw-lw0,stk(lw0),1,stk(l0),1)      
       return
       end	
 
