@@ -306,7 +306,7 @@ c     f macro j macro
      2              stk(lrwp),ilrw,istk(ilc),liwp,mf)
             endif
          endif
-         if(err.gt.0) return
+         if(err.gt.0.or.err1.gt.0) return
          if(istate.lt.0) then
             call error(24)
             return
@@ -705,7 +705,7 @@ c     not enough memory
      &           stk(lrwork),lrw,istk(iadr(liwork)),liw,stk(lw15),
      &           istk(il17),bjacd)
          endif
-         if(err.gt.0)  return
+         if(err.gt.0.or.err1.gt.0)  return
          if(idid.eq.1) then
 C     A step was successfully taken in the intermediate-output mode. 
 C     The code has not yet reached TOUT.
