@@ -2124,13 +2124,27 @@ c     implied polynomials vector extraction
 
       if(mn2.eq.0) then 
 c     .  arg2=[]
-         il1=iadr(lstk(top))
-         istk(il1)=1
-         istk(il1+1)=0
-         istk(il1+2)=0
-         istk(il1+3)=0
-         lstk(top+1)=sadr(il1+4)
+         if(m1.le.0) then
+c            arg2(:) or arg2([])
+            il1=iadr(lstk(top))
+            istk(il1)=1
+            istk(il1+1)=0
+            istk(il1+2)=0
+            istk(il1+3)=0
+            lstk(top+1)=sadr(il1+4)
+         else
+c     should be an error but a lot of code uses this feature
+c     we will change it just after 3.1 release  see also matext2
+c            call error(21)
+            il1=iadr(lstk(top))
+            istk(il1)=1
+            istk(il1+1)=0
+            istk(il1+2)=0
+            istk(il1+3)=0
+            lstk(top+1)=sadr(il1+4)
+         endif
          return
+
       elseif(m2.lt.0) then
 c     .  arg2=eye
          call error(14)
@@ -2253,12 +2267,26 @@ c     arg3(arg1,arg2)
       endif
       if(mn3.eq.0) then 
 c     .  arg3=[]
-         il1=iadr(lstk(top))
-         istk(il1)=1
-         istk(il1+1)=0
-         istk(il1+2)=0
-         istk(il1+3)=0
-         lstk(top+1)=sadr(il1+4)
+         if(m1.le.0.or.m2.le.0) then
+            il1=iadr(lstk(top))
+            istk(il1)=1
+            istk(il1+1)=0
+            istk(il1+2)=0
+            istk(il1+3)=0
+            lstk(top+1)=sadr(il1+4)
+         else
+c     should be an error but a lot of code uses this feature
+c     we will change it just after 3.1 release see also matext1
+
+c           call error(21)
+            il1=iadr(lstk(top))
+            istk(il1)=1
+            istk(il1+1)=0
+            istk(il1+2)=0
+            istk(il1+3)=0
+            lstk(top+1)=sadr(il1+4)
+
+         endif
          return
       elseif(m3.lt.0) then
 c     .arg3=eye
@@ -2336,6 +2364,7 @@ c
       logical isany
       integer top0
       integer iadr,sadr
+      double precision xr,xi
 c     
       iadr(l)=l+l-1
       sadr(l)=(l/2)+1
@@ -2436,14 +2465,29 @@ c     .  arg3(:)=arg2
             call unsfdcopy((it2+1)*mn2,stk(l2),1,stk(l1),1)
             lstk(top+1)=l1+mn2*(it2+1)
             return
+         elseif(mn3.eq.0) then
+            istk(ilrs)=1
+            istk(ilrs+1)=m2
+            istk(ilrs+2)=n2
+            istk(ilrs+3)=it2
+            l1=sadr(ilrs+4)
+            call unsfdcopy((it2+1)*mn2,stk(l2),1,stk(l1),1)
+            lstk(top+1)=l1+mn2*(it2+1)
+            return
          elseif(mn2.eq.1) then
             istk(ilrs)=1
             istk(ilrs+1)=m3
             istk(ilrs+2)=n3
             istk(ilrs+3)=it2
             l1=sadr(ilrs+4)
-            call dset(mn3,stk(l2),stk(l1),1)
-            if(it2.eq.1) call dset(mn3,stk(l2+1),stk(l1+mn3),1)
+            if (it2.eq.1) then
+               xr=stk(l2)
+               xi=stk(l2+1)
+               call dset(mn3,xr,stk(l1),1)
+               call dset(mn3,xi,stk(l1+mn3),1)
+            else
+               call dset(mn3,stk(l2),stk(l1),1)
+            endif
             lstk(top+1)=l1+mn3*(it2+1)
             return
          else
@@ -2817,8 +2861,36 @@ c     .     set all elements of arg4 to arg3
             call error(15)
             return
          endif
-      endif
 
+      endif
+      init4=0
+      if(m1.eq.-1.and.m4.eq.0) then
+c     .  arg4(:,i)=arg3
+         m3=m3*n3
+         n3=1
+         n4=1
+         m4=m3
+         init4=1
+         
+      elseif(m2.eq.-1.and.m4.eq.0) then
+c     .  arg4(i,:)=arg3
+         n3=m3*n3
+         m3=1
+         m4=1
+         n4=n3
+         init4=1
+      endif
+      if(init4.eq.1) then
+         err=lw-lstk(bot)
+         if(err.gt.0) then
+            call error(17)
+            return
+         endif
+         mn4=m4*n4
+         l4=lw
+         lw=l4+ mn4
+         call dset(mn4,0.0d0,stk(l4),1)
+      endif
       call indxg(il1,m4,ili,mi,mxi,lw,1)
       if(err.gt.0) return
       call indxg(il2,n4,ilj,mj,mxj,lw,1)
@@ -2887,7 +2959,7 @@ c     copy arg3 elements in r
  114     continue
  115  continue
 c     
-      if(lr.ne.l4) then
+      if(lr.ne.l4.or.init4.ne.0) then
          l1=sadr(ilrs+4)
          call unsfdcopy(mnr*(itr+1),stk(lr),1,stk(l1),1)
          istk(ilrs)=1
@@ -3107,8 +3179,8 @@ c     .  eye op b
             top=top0
             return
          endif
-         itrue=1
-         if(op.eq.less+great) itrue=0
+c         itrue=1
+c         if(op.eq.less+great) itrue=0
          istk(il1)=4
          do 131 i=0,mn1-1
             e1r=stk(l1+i)
@@ -3117,11 +3189,22 @@ c     .  eye op b
             e2i=0.0d+0
             if(it1.eq.1) e1i=stk(l1+mn1+i)
             if(it2.eq.1) e2i=stk(l2+mn2+i)
-            if(e1r.eq.e2r.and.e1i.eq.e2i) then
-               istk(il1+3+i)=itrue
+            call idcmp(e1r,e2r,1,ir,op)
+            call idcmp(e1i,e2i,1,ii,op)
+            if (op.eq.less+great) then
+               if(ir.eq.1.or.ii.eq.1) then
+                  istk(il1+3+i)=1
+               else
+                  istk(il1+3+i)=0
+               endif
             else
-               istk(il1+3+i)=1-itrue
+               if(ir.eq.1.and.ii.eq.1) then
+                  istk(il1+3+i)=1
+               else
+                  istk(il1+3+i)=0
+               endif
             endif
+
  131     continue
          lstk(top+1)=sadr(il1+3+mn1)
       else
