@@ -1,6 +1,7 @@
 #ifndef STACK1_H 
 #define STACK1_H 
 
+
 typedef  void (*S_fp) __PARAMS((char *,int *));
 
 /** used in stack1.c : defined elsewhere */
@@ -15,7 +16,12 @@ extern void C2F(cstringf) __PARAMS((char ***,integer *,integer *,integer *,integ
 extern int s_copy __PARAMS((char *,char *, integer, unsigned long int));
 extern int C2F(stringc)  __PARAMS((integer *,char ***,integer *));
 extern int C2F(stackg)   __PARAMS((integer *));
-extern int  Scierror __PARAMS((int iv,char *fmt,...));
+
+#ifdef __STDC__
+	extern int  Scierror __PARAMS((int iv,char *fmt,...));
+#else
+	extern int Scierror __PARAMS(()) ;
+#endif 
 
 /* calelm */
 
@@ -72,6 +78,7 @@ extern int C2F(cresparsei)  __PARAMS((char *fname, integer *stlw, integer *it, i
 extern int C2F(getlistvect)  __PARAMS((char *fname, integer *topk, integer *spos, integer *lnum, integer *it, integer *m, integer *n, integer *lr, integer *lc, unsigned long fname_len));
 extern int C2F(getvect)  __PARAMS((char *fname, integer *topk, integer *lw, integer *it, integer *m, integer *n, integer *lr, integer *lc, unsigned long fname_len));
 extern int C2F(getrmat)  __PARAMS((char *fname, integer *topk, integer *lw, integer *m, integer *n, integer *lr, unsigned long fname_len));
+extern int C2F(getcmat)  __PARAMS((char *fname, integer *topk, integer *lw, integer *m, integer *n, integer *lr, unsigned long fname_len));
 extern int C2F(getrvect)  __PARAMS((char *fname, integer *topk, integer *lw, integer *m, integer *n, integer *lr, unsigned long fname_len));
 extern int C2F(getscalar)  __PARAMS((char *fname, integer *topk, integer *lw, integer *lr, unsigned long fname_len));
 extern int C2F(matsize)  __PARAMS((char *fname, integer *topk, integer *lw, integer *m, integer *n, unsigned long fname_len));
