@@ -27,15 +27,18 @@ c
 c
       double precision dt,ymin,ymax,per,rect(4),tsave
       integer i,n,verb,cur,na,v,wid,nax(4)
-      character*20 strf,buf
+      character*40 strf,buf
       double precision dv
       double precision frect(4)
       character*(4) logf
       character*4 name
       logical herited
 
+      integer kfun
+      common /curblk/ kfun
       data cur/0/,verb/0/
 
+
 c     
       call dr1('xgetdr'//char(0),name,v,v,v,v,v,v,
      $     dv,dv,dv,dv)
@@ -112,12 +115,16 @@ c     loop on input ports
                frect(3)=1.0d0
                frect(4)=(1.0d0/nwid)
                call  setscale2d(frect,rect,'nn'//char(0))
+               call scicosclip(1)
+
 c     loop on input port elements
                do 10 i=1,ipar(7+kwid)
                   call dr1('xpolys'//char(0),'v'//char(0),v,v,
      $                 ipar(ilt+it),1,K,v,z(2),z(2+N+it*N),dv,dv)
                   it=it+1
  10            continue
+            call scicosclip(0)
+
  11         continue
          endif
 c     shift buffer left
@@ -195,6 +202,14 @@ c
          strf='011'//char(0)
          call dr1('xset'//char(0),'dashes'//char(0),0,0,0,
      &        0,0,v,dv,dv,dv,dv)
+         nxname=40
+         call getlabel(kfun,buf,nxname)
+         if(nxname.gt.39) nxname=39
+         buf(nxname+1:nxname+1)=char(0)
+         if ((nxname.eq.1.and.buf(1:1).eq.' ').or.(nxname.eq.0)) then
+         else
+            call dr('xname'//char(0),buf,v,v,v,v,v,v,dv,dv,dv,dv)
+         endif
 
          do 20 kwid=1,nwid
             rect(1)=per*(1+n1)
@@ -241,12 +256,15 @@ c     loop on input ports
             frect(3)=1.0d0
             frect(4)=(1.0d0/nwid)
             call  setscale2d(frect,rect,'nn'//char(0))
+            call scicosclip(1)
+
 c     loop on input port elements
             do 30 i=1,ipar(7+kwid)
                call dr1('xpolys'//char(0),'v'//char(0),v,v,ipar(ilt
      $              +it),1,K-1,v,z(2),z(2+N+it*N),dv,dv)
                it=it+1
  30         continue
+               call scicosclip(0)
  35      continue
       endif
 
