@@ -1,4 +1,4 @@
-/* 11-03-2005, Masoud*/
+/* 11-03-2005,  Masoud*/
 /* adding A-Jacobian*/
 /* istate =-1 case;*/
 
@@ -537,6 +537,7 @@ int C2F(scicos)
     /*     fermeture des blocks */
     cosend(t0);
   } else if (*flag__ == 4) {
+    phase=1;
     idoit(t0);
     if (*ierr == 0) {
       if((W=MALLOC(sizeof(double)*nx))== NULL ){
@@ -777,6 +778,12 @@ int C2F(scicos)
     FREE(ihot);
     return;
   }
+
+  for ( jj = 0 ; jj < ng ; jj++ )
+  {
+	jroot[jj] = 0 ;
+  }
+
   if((zcros=MALLOC(sizeof(int)*ng))== NULL ){
     *ierr =10000;
     FREE(rhot);
@@ -924,12 +931,28 @@ int C2F(scicos)
 	  C2F(dset)(&panj, &c_b14, &rhot[5], &c__1);
 	  rhot[6]=hmax;
 	}
-	phase=2;
-	C2F(lsodar2)(C2F(simblk), neq, x, told, &t, &c__1, &rtol, 
-		     &Atol, &itask, &istate, &iopt, &rhot[1], &
-		     nrwp, &ihot[1], &niwp, &jdum, &jt, 
-		     C2F(grblk), &ng, jroot);
+
+	/*--discrete zero crossings----dzero--------------------*/
+	/*--check for Dzeros after Mode settings or ddoit()----*/
+	if (ng>0 && hot==0){
+	  zdoit(W, x, x,told);
+	  if (*ierr != 0) {freeall;return;}
+	  for (jj = 0; jj < ng; ++jj) {
+	    if((W[jj]>=0.0)&&(jroot[jj]==-5)) {istate=3;jroot[jj]=1;}
+	    else if((W[jj]<0.0)&&(jroot[jj]==5)) {istate=3;jroot[jj]=-1;}
+	  }
+	} 
+	/*--discrete zero crossings----dzero--------------------*/
+
+	if (istate!=3){/* if there was a dzero, its event should be activated*/
+	  phase=2;
+	  C2F(lsodar2)(C2F(simblk), neq, x, told, &t, &c__1, &rtol, 
+		       &Atol, &itask, &istate, &iopt, &rhot[1], &
+		       nrwp, &ihot[1], &niwp, &jdum, &jt, 
+		       C2F(grblk), &ng, jroot);
+	}
 	phase=1;
+	
 	if (*ierr > 5) {
 	  /*     !           singularity in block */
 	  freeall;
@@ -1012,7 +1035,7 @@ int C2F(scicos)
 		  }
 		}
 		/*     .              update state */
-		if (Blocks[C2F(curblk).kfun-1].nx > 0) {
+		if ((Blocks[C2F(curblk).kfun-1].nx > 0) || (*Blocks[C2F(curblk).kfun-1].work != NULL) ) {
 		  /*     .              call corresponding block to update state */
 		  flag__ = 2;
 		  nclock = -kev;
@@ -1029,6 +1052,14 @@ int C2F(scicos)
 	  }
 	}
       }
+      /*--discrete zero crossings----dzero--------------------*/
+      if (ng>0){ /* storing ZC signs just after a ddaskr call*/
+	zdoit(W, x, x, told); if (*ierr != 0) {freeall;return;  }
+	for (jj = 0; jj < ng; ++jj) 
+	  if(W[jj]>=0)jroot[jj]=5;else jroot[jj]=-5;
+      }
+      /*--discrete zero crossings----dzero--------------------*/
+
       C2F(realtime)(told);
     } else {
       /*     .  t==told */   
@@ -1147,7 +1178,7 @@ int C2F(scicos)
     FREE(zcros);
     return;
   }
-  if((Mode_save=MALLOC(sizeof(double)*nmod))== NULL ){
+  if((Mode_save=MALLOC(sizeof(integer)*nmod))== NULL ){
     *ierr =10000;
     FREE(rhot);
     FREE(ihot);
@@ -1385,10 +1416,26 @@ int C2F(scicos)
 	if (C2F(cosdebug).cosd >= 1) {
 	  sciprint("****daskr from: %f to %f hot= %d  \r\n", *told,t,hot);
 	}
+
+	/*--discrete zero crossings----dzero--------------------*/
+	/*--check for Dzeros after Mode settings or ddoit()----*/
+	if (ng>0 && hot==0){
+	  zdoit(W, xd, x,told);
+	  if (*ierr != 0) {freeallx;return;  }
+	  istate=0;
+	  for (jj = 0; jj < ng; ++jj) {
+	    if((W[jj]>=0.0)&&( jroot[jj]==-5)) {istate=5;jroot[jj]=1;}
+	    else if((W[jj]<0.0)&&( jroot[jj]==5)) {istate=5;jroot[jj]=-1;}
+	    else jroot[jj]=0;
+	  }
+	} 
+	/*--discrete zero crossings----dzero--------------------*/
+	if (istate!=5){/* if there was a dzero, its event should be activated*/
 	C2F(ddaskr)(C2F(simblkdaskr), neq, told, x, xd, &t, 
 		    info, &rtol, &Atol, &istate, &rhot[1], &
 		    nrwp, &ihot[1], &niwp, rpardummy, ipardummy
 		    ,C2F(Jacobian), rpardummy, C2F(grblkdaskr), &ng, jroot);
+	}
 
 	if (istate == -1)
 	  sciprint("**** Stiffness at: %26.18f %d\r\n",*told,istate);
@@ -1398,7 +1445,7 @@ int C2F(scicos)
 	  freeallx; /* singularity in block */
 	  return;
 	}
-	
+	 
 	if (istate <= -2) { /* in case istate==-1 : continue the integration*/
 	  *ierr = 100 - istate;
 	  freeallx;/* singularity in block */
@@ -1510,6 +1557,14 @@ int C2F(scicos)
 	      goto L15;
 	    }
 	    }*/
+
+	/*--discrete zero crossings----dzero--------------------*/
+	if (ng>0){ /* storing ZC signs just after a ddaskr call*/
+	  zdoit(W, xd, x, told); if (*ierr != 0) {freeallx;return;  }
+	  for (jj = 0; jj < ng; ++jj) 
+	    if(W[jj]>=0)jroot[jj]=5;else jroot[jj]=-5;
+	}
+	/*--discrete zero crossings----dzero--------------------*/
       }
       C2F(realtime)(told);
     } else {
@@ -1962,7 +2017,7 @@ int C2F(scicos)
       }
     }
     
-    if (Blocks[C2F(curblk).kfun - 1].nevout > 0) {
+    if (Blocks[C2F(curblk).kfun - 1].nevout > 0 && funtyp[C2F(curblk).kfun] < 0) {
       if (funtyp[C2F(curblk).kfun] == -1) {
 	if (outtb[-1+lnkptr[inplnk[inpptr[C2F(curblk).kfun]]]] <= 0.) {
 	  i=2;
@@ -2372,6 +2427,11 @@ callf(t,xtd,xt,residual,g,flag)
       Blocks[kf-1].res=&residual[xptr[kf]-1];
     }
   }
+  else
+  {
+	Blocks[kf-1].x  = NULL ;
+	Blocks[kf-1].xd = NULL ;
+  }
 
   switch (Blocks[kf-1].type) {
 
@@ -2427,9 +2487,8 @@ callf(t,xtd,xt,residual,g,flag)
     break;   
   case 0 :			
     /* concatenated entries and concatened outputs */
-    ni=0;
     /* catenate inputs if necessary */
-
+    ni=0;
     if (Blocks[kf-1].nin>1) {
       ki=0;
       for (in=0;in<Blocks[kf-1].nin;in++) {
