@@ -47,8 +47,6 @@
 #ifndef lint
 static char copyright[] =
     "Sparse1.3: Copyright (c) 1985,86,87,88 by Kenneth S. Kundert";
-static char RCSid[] =
-    "@(#)$Header: /usr/local/cvsroot/scilab2.7/routines/sparse/spBuild.c,v 1.1.1.1 2001/04/26 07:48:07 scilab Exp $";
 #endif
 
 
@@ -887,7 +885,7 @@ register  int  Col;
         }
     }
     Matrix->RowsLinked = YES;
-    return;
+    return 0;
 }
 
 
@@ -925,31 +923,31 @@ register int I, OldAllocatedSize = Matrix->AllocatedSize;
     Matrix->Size = NewSize;
 
     if (NewSize <= OldAllocatedSize)
-        return;
+        return 0;
 
 /* Expand the matrix frame. */
-    NewSize = MAX( NewSize, EXPANSION_FACTOR * OldAllocatedSize );
+    NewSize = (int) MAX( NewSize, EXPANSION_FACTOR * OldAllocatedSize );
     Matrix->AllocatedSize = NewSize;
 
     if (( REALLOC(Matrix->IntToExtColMap, int, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
     if (( REALLOC(Matrix->IntToExtRowMap, int, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
     if (( REALLOC(Matrix->Diag, ElementPtr, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
     if (( REALLOC(Matrix->FirstInCol, ElementPtr, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
     if (( REALLOC(Matrix->FirstInRow, ElementPtr, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
 
 /*
@@ -973,7 +971,7 @@ register int I, OldAllocatedSize = Matrix->AllocatedSize;
         Matrix->FirstInCol[I] = NULL;
     }
 
-    return;
+    return 0;
 }
 
 
@@ -1014,19 +1012,19 @@ register int I, OldAllocatedSize = Matrix->AllocatedExtSize;
     Matrix->ExtSize = NewSize;
 
     if (NewSize <= OldAllocatedSize)
-        return;
+        return 0;
 
 /* Expand the translation arrays ExtToIntRowMap and ExtToIntColMap. */
-    NewSize = MAX( NewSize, EXPANSION_FACTOR * OldAllocatedSize );
+    NewSize = (int) MAX( NewSize, EXPANSION_FACTOR * OldAllocatedSize );
     Matrix->AllocatedExtSize = NewSize;
 
     if (( REALLOC(Matrix->ExtToIntRowMap, int, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
     if (( REALLOC(Matrix->ExtToIntColMap, int, NewSize+1)) == NULL)
     {   Matrix->Error = spNO_MEMORY;
-        return;
+        return 0;
     }
 
 /* Initialize the new portion of the vectors. */
@@ -1035,7 +1033,7 @@ register int I, OldAllocatedSize = Matrix->AllocatedExtSize;
         Matrix->ExtToIntColMap[I] = -1;
     }
 
-    return;
+    return 0;
 }
 #endif
 
