@@ -234,18 +234,27 @@ c     . hard predefined variables
       gbot=isizt
       lstk(gbot)=lstk(gtop+1)+vsizg-1
 c
-c     12 is the number of predefined variables 
-      bot=isiz-12
+C     If you want to add more predefined variables, takle care of the
+C     following points:
+C     - You have to update the number of predefined variable (npredef)
+C       ignoring bl
+c     - To update the total amount of memory (lpvar) used by all the predefined
+C       variables .
+c       memory requested for each type of predefined variables 
+c       mxn boolean matrix size : sadr(2+m*n+2)        --> sadr(5) for a boolean scalar
+c       mxn  matrix size        : sadr(3)+m*n*(it+1))  --> sadr(3)+1 for a real scalar
+c       1x1 string matrix       : sadr(6+nchar)+1
+c       $                       : sadr(10-1) + 2 
+c     - add the new variable at the beginning
+      npredef=13
+
+      bot=isiz-npredef
       bbot=bot
       bot0=bot
-c     memory requested for predefined variables 
-c     mxn bmat -> size : sadr(2+m*n+2)
-c     $        -> size : sadr(10-1) + 2 
-c     mxn mat  -> size : sadr(3)+m*n*(it+1)
-c     string   -> size : sadr(6+nchar)+1
       call getcomp(buf,nbuf)
+c     1 $, 6 booleans , 4 real scalar, 2 2x1 real array, 1 string     
       lpvar = (sadr(10-1) + 2) 
-     $     + 5*sadr(5) 
+     $     + 6*sadr(5) 
      $     + 4*(sadr(3)+1)
      $     + 2*(sadr(3)+2)
      $     + 1*(sadr(6+nbuf)+1)
@@ -265,6 +274,12 @@ c     . %gtk
       call cvname(idloc,vname,0)
       call crebmatvar(idloc,k,1,1,irep)
       k=k+1
+c     . %gui
+      vname(1:4) = "%gui"
+      call withgui(irep)
+      call cvname(idloc,vname,0)
+      call crebmatvar(idloc,k,1,1,irep)
+      k=k+1
 c     . %pvm
       vname(1:4) = "%pvm"
       call withpvm(irep)
