@@ -131,8 +131,7 @@ int C2F(parse)()
 			    673720360,673720360 };
   static int varargout[6] = { 169544223,504893467,673720349,673720360,
 				  673720360,673720360 };
-  static int catch[6] = {203229708,673720337,673720360,673720360,
-				  673720360,673720360 };
+  /* static int catch[6] = {203229708,673720337,673720360,673720360, 673720360,673720360 };*/
 
   static int *Ids     = C2F(recu).ids-nsiz-1;
   static int *Rstk    = C2F(recu).rstk-1;
@@ -141,8 +140,8 @@ int C2F(parse)()
   static int *Lin     = C2F(iop).lin-1;
   static int *Lpt     = C2F(iop).lpt-1;
   static int *Lct     = C2F(iop).lct-1;
-  static double *Stk  = C2F(stack).Stk-1;
-  static int    *Istk = (int *)( C2F(stack).Stk)-1;
+  /*static double *Stk  = C2F(stack).Stk-1;*/
+  /*static int    *Istk = (int *)( C2F(stack).Stk)-1;*/
 
   /* System generated locals */
   int i__2, i__3;
@@ -282,13 +281,12 @@ int C2F(parse)()
   /*     Beginning of a new statement, clause expression or command */
   /* ------------------------------------------------------------ */
  L15:
-  if (inxsci == 1 && scilab_timer_check() ) {
-    C2F(sxevents)();
-    if (C2F(ismenu)() == 1 && C2F(basbrk).interruptible) {
-      iret = 1;
-      goto L96;
-    }
+  if (inxsci == 1 && scilab_timer_check() ) C2F(sxevents)();
+  if (C2F(ismenu)() == 1 && C2F(basbrk).interruptible) {
+    iret = 1;
+    goto L96;
   }
+
   r = 0;
   if (Pt > 0) {
     r = Rstk[Pt];
@@ -998,21 +996,31 @@ int C2F(parse)()
     else
       goto L15;
   }
+
   /*     gestion des points d'arrets dynamiques */
-  if (C2F(dbg).wmac != 0) {
-    i__2 = Lpt[2] - 1;
-    C2F(whatln)(&Lpt[1], &i__2, &Lpt[6], &nlc, &l1, &ifin);
-    i__2 = C2F(dbg).lgptrs[C2F(dbg).wmac] - 1;
-    for (ibpt = C2F(dbg).lgptrs[C2F(dbg).wmac - 1]; ibpt <= i__2; ++ibpt) {
-      if (Lct[8] - nlc == C2F(dbg).bptlg[ibpt - 1]) {
-	C2F(cvname)(&C2F(dbg).macnms[C2F(dbg).wmac * nsiz - 6], tmp, &c__1, 24L);
-	sprintf(C2F(cha1).buf,"%s %5d",tmp, Lct[8] - nlc);
-	Msgs(32,0);
-	i__3 = ifin - l1 + 1;
-	C2F(cvstr)(&i__3, &Lin[l1], C2F(cha1).buf, &c__1, bsiz);
-	C2F(basout)(&io, &C2F(iop).wte, C2F(cha1).buf, ifin - l1 + 1);
-	C2F(basbrk).iflag = TRUE_;
-	goto L79;
+  if (C2F(dbg).nmacs != 0) { /* there are breakpoints set */
+    int kfin=C2F(dbg).wmac-1; /*the stack index of the current function*/
+    /*  first test if the function has breakpoints   */
+    int kmac;
+    for (kmac=0;kmac<C2F(dbg).nmacs;kmac++) { /* loop on table of functions containing breakpoints */
+      /* does the name of the current funtion fit the registered name*/
+      if (C2F(eqid)(&(C2F(vstk).idstk[kfin * nsiz]), &(C2F(dbg).macnms[kmac * nsiz]))) {/* yes */
+	/* test if there is a registered breakpoint at the current line*/
+	i__2 = Lpt[2] - 1;
+	C2F(whatln)(&Lpt[1], &i__2, &Lpt[6], &nlc, &l1, &ifin);
+	i__2 = C2F(dbg).lgptrs[kmac+1] - 1;
+	for (ibpt = C2F(dbg).lgptrs[kmac]; ibpt <= i__2; ++ibpt) {
+	  if (Lct[8] - nlc == C2F(dbg).bptlg[ibpt - 1]) { /* yes */
+	    /* display a message */
+	    C2F(cvname)(&C2F(dbg).macnms[kmac * nsiz], tmp, &c__1, 24L);
+	    sprintf(C2F(cha1).buf,"%s %5d",tmp, Lct[8] - nlc);
+	    Msgs(32, 0);
+	    /* raise the interruption flag */
+	    C2F(basbrk).iflag = TRUE_;
+	    goto L79;
+	  }
+	}
+	break;
       }
     }
   }
@@ -1670,10 +1678,12 @@ int C2F(syncexec)(str, ns, ierr, seq, str_len)
   *ierr = 0;
   C2F(recu).icall = 0;
   C2F(com).fin = 3;
+  C2F(basbrk).interruptible = TRUE_;
   return 0;
  L9998:
   *ierr = 1;
   Pt=Pts;Top=Tops;
+  C2F(basbrk).interruptible = TRUE_;
 
   return 0;
  L9999:
@@ -1682,6 +1692,7 @@ int C2F(syncexec)(str, ns, ierr, seq, str_len)
   --Top;
   --C2F(recu).niv;
   Pt=Pts;Top=Tops;
+  C2F(basbrk).interruptible = TRUE_;
   return 0;
 } /* syncexec */
 
