@@ -127,6 +127,12 @@ c+
       return
 c     
  9999 continue
+      if(err1.gt.0) then
+         lhs=ids(1,pt)
+         rhs=ids(2,pt)
+         pt=pt-1
+         fun=0
+      endif
       iero=1
       niv=niv-1
       return
