@@ -68,23 +68,23 @@
 #include <X11/Xos.h>
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
-#include <X11/Xaw/Cardinals.h>
+#include <X11/Xaw3d/Cardinals.h>
 #include <X11/Xatom.h>
 #include <X11/Shell.h>
-#include <X11/Xaw/Paned.h>
-#include <X11/Xaw/Grip.h>
-#include <X11/Xaw/Form.h>
-#include <X11/Xaw/MenuButton.h>
-#include <X11/Xaw/SimpleMenu.h>
-#include <X11/Xaw/SmeBSB.h>
-#include <X11/Xaw/AsciiText.h>
-#include <X11/Xaw/TextSrc.h>
-#include <X11/Xaw/Text.h>
-#include <X11/Xaw/Box.h>
-#include <X11/Xaw/Dialog.h>
-#include <X11/Xaw/List.h>
-#include <X11/Xaw/Command.h>
-#include <X11/Xaw/Label.h>
+#include <X11/Xaw3d/Paned.h>
+#include <X11/Xaw3d/Grip.h>
+#include <X11/Xaw3d/Form.h>
+#include <X11/Xaw3d/MenuButton.h>
+#include <X11/Xaw3d/SimpleMenu.h>
+#include <X11/Xaw3d/SmeBSB.h>
+#include <X11/Xaw3d/AsciiText.h>
+#include <X11/Xaw3d/TextSrc.h>
+#include <X11/Xaw3d/Text.h>
+#include <X11/Xaw3d/Box.h>
+#include <X11/Xaw3d/Dialog.h>
+#include <X11/Xaw3d/List.h>
+#include <X11/Xaw3d/Command.h>
+#include <X11/Xaw3d/Label.h>
 #include <X11/cursorfont.h>
 
 /* incompatibility of header file with X11R4 documentation */
